==> qore-0.9.4.tar.bz2: qore-0.9.4/docs/modules/SalesforceRestDataProvider/html/class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.js <==
var class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator =
[
    [ "constructor", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#ad68e0054b791386abf9edb9e6e63d0fa", null ],
    [ "getOrClause", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#a0ac058d5dbc720d7901fa067fad9bf57", null ],
    [ "getValue", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#a56df8a2e8d0d8fb17675333935514f09", null ],
    [ "makeQuery", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#ab3a0927d625130d7a88af12de586f74b", null ],
    [ "memberGate", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#aa4035b7117fa3d174c60ea6a72f3c7da", null ],
    [ "next", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#aca8f37fe2be184cd42c942605f92762c", null ],
    [ "valid", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#a92570fa57755c2f4c3726c6f0a86b85f", null ],
    [ "i", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#a776141cecb4a379b698a89b55cc152a2", null ],
    [ "name", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#a455f2f0960c226a9111f2f90f242e9cb", null ],
    [ "record_info", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#a31ef388aee2bd8396f3fb7ae00e8613c", null ],
    [ "rest", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#a3ce2d5d953d197e3cf4de0d0a58899cb", null ]
];

==> qore-1.6.0.tar.bz2: qore-1.6.0/docs/modules/SalesforceRestDataProvider/html/class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.js <==
var class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator =
[
    [ "constructor", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#ad68e0054b791386abf9edb9e6e63d0fa", null ],
    [ "getOrClause", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#a0ac058d5dbc720d7901fa067fad9bf57", null ],
    [ "getRecordType", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#a932d835459c47e4cee21aa87a841933a", null ],
    [ "getValue", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#a56df8a2e8d0d8fb17675333935514f09", null ],
    [ "makeQuery", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#ab3a0927d625130d7a88af12de586f74b", null ],
    [ "memberGate", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#aa4035b7117fa3d174c60ea6a72f3c7da", null ],
    [ "next", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#aca8f37fe2be184cd42c942605f92762c", null ],
    [ "valid", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#a92570fa57755c2f4c3726c6f0a86b85f", null ],
    [ "i", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#a776141cecb4a379b698a89b55cc152a2", null ],
    [ "name", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#a455f2f0960c226a9111f2f90f242e9cb", null ],
    [ "record_info", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#a31ef388aee2bd8396f3fb7ae00e8613c", null ],
    [ "rest", "class_salesforce_rest_data_provider_1_1_salesforce_rest_record_iterator.html#a3ce2d5d953d197e3cf4de0d0a58899cb", null ]
];
